==> ant-design-vue-2.1.6.jar: META-INF/resources/webjars/ant-design-vue/2.1.6/es/locale-provider/ta_IN.d.ts <==
declare const _default: {
    locale: string;
    Pagination: {
        items_per_page: string;
        jump_to: string;
        jump_to_confirm: string;
        page: string;
        prev_page: string;
        next_page: string;
        prev_5: string;
        next_5: string;
        prev_3: string;
        next_3: string;
    };
    DatePicker: {
        lang: {
            today: string;
            now: string;
            backToToday: string;
            ok: string;
            clear: string;
            month: string;
            year: string;
            timeSelect: string;
            dateSelect: string;
            weekSelect: string;
            monthSelect: string;
            yearSelect: string;
            decadeSelect: string;
            yearFormat: string;
            dateFormat: string;
            dayFormat: string;
            dateTimeFormat: string;
            monthBeforeYear: boolean;
            previousMonth: string;
            nextMonth: string;
            previousYear: string;
            nextYear: string;
            previousDecade: string;
            nextDecade: string;
            previousCentury: string;
            nextCentury: string;
            placeholder: string;
            rangePlaceholder: string[];
        };
        timePickerLocale: {
            placeholder: string;
        };
    };
    TimePicker: {
        placeholder: string;
    };
    Calendar: {
        lang: {
            today: string;
            now: string;
            backToToday: string;
            ok: string;
            clear: string;
            month: string;
            year: string;
            timeSelect: string;
            dateSelect: string;
            weekSelect: string;
            monthSelect: string;
            yearSelect: string;
            decadeSelect: string;
            yearFormat: string;
            dateFormat: string;
            dayFormat: string;
            dateTimeFormat: string;
            monthBeforeYear: boolean;
            previousMonth: string;
            nextMonth: string;
            previousYear: string;
            nextYear: string;
            previousDecade: string;
            nextDecade: string;
            previousCentury: string;
            nextCentury: string;
            placeholder: string;
            rangePlaceholder: string[];
        };
        timePickerLocale: {
            placeholder: string;
        };
    };
    global: {
        placeholder: string;
    };
    Table: {
        filterTitle: string;
        filterConfirm: string;
        filterReset: string;
        emptyText: string;
        selectAll: string;
        selectInvert: string;
        sortTitle: string;
    };
    Modal: {
        okText: string;
        cancelText: string;
        justOkText: string;
    };
    Popconfirm: {
        okText: string;
        cancelText: string;
    };
    Transfer: {
        titles: string[];
        notFoundContent: string;
        searchPlaceholder: string;
        itemUnit: string;
        itemsUnit: string;
    };
    Upload: {
        uploading: string;
        removeFile: string;
        uploadError: string;
        previewFile: string;
    };
    Empty: {
        description: string;
    };
    Icon: {
        icon: string;
    };
    Text: {
        edit: string;
        copy: string;
        copied: string;
        expand: string;
    };
    PageHeader: {
        back: string;
    };
};
export default _default;

==> ant-design-vue-3.2.19.jar: META-INF/resources/webjars/ant-design-vue/3.2.19/es/locale-provider/ta_IN.d.ts <==
declare const _default: {
    locale: string;
    Pagination: {
        items_per_page: string;
        jump_to: string;
        jump_to_confirm: string;
        page: string;
        prev_page: string;
        next_page: string;
        prev_5: string;
        next_5: string;
        prev_3: string;
        next_3: string;
    };
    DatePicker: import("../date-picker/generatePicker").PickerLocale;
    TimePicker: import("../time-picker").TimePickerLocale;
    Calendar: import("../date-picker/generatePicker").PickerLocale;
    global: {
        placeholder: string;
    };
    Table: {
        filterTitle: string;
        filterConfirm: string;
        filterReset: string;
        emptyText: string;
        selectAll: string;
        selectInvert: string;
        sortTitle: string;
    };
    Modal: {
        okText: string;
        cancelText: string;
        justOkText: string;
    };
    Popconfirm: {
        okText: string;
        cancelText: string;
    };
    Transfer: {
        titles: string[];
        notFoundContent: string;
        searchPlaceholder: string;
        itemUnit: string;
        itemsUnit: string;
    };
    Upload: {
        uploading: string;
        removeFile: string;
        uploadError: string;
        previewFile: string;
    };
    Empty: {
        description: string;
    };
    Icon: {
        icon: string;
    };
    Text: {
        edit: string;
        copy: string;
        copied: string;
        expand: string;
    };
    PageHeader: {
        back: string;
    };
};
export default _default;
